@@ -369,7 +369,7 @@ class Unet3D(nn.Module):
         init_padding = init_kernel_size // 2
         self.init_conv = nn.Conv3d(channels, init_dim, (1, init_kernel_size, init_kernel_size), padding = (0, init_padding, init_padding))
 
-        self.init_temporal_attn = temporal_attn(init_dim)
+        self.init_temporal_attn = Residual(PreNorm(init_dim, temporal_attn(init_dim)))
 
         # dimensions
 
@@ -473,8 +473,10 @@ class Unet3D(nn.Module):
 
         focus_present_mask = prob_mask_like((batch,), prob_focus_present, device = device)
 
+        time_rel_pos_bias = self.time_rel_pos_bias(x.shape[2], device = x.device)
+
         x = self.init_conv(x)
-        x = self.init_temporal_attn(x)
+        x = self.init_temporal_attn(x, pos_bias = time_rel_pos_bias)
 
         t = self.time_mlp(time) if exists(self.time_mlp) else None
 
@@ -488,8 +490,6 @@ class Unet3D(nn.Module):
 
         h = []
 
-        time_rel_pos_bias = self.time_rel_pos_bias(x.shape[2], device = x.device)
-
         for block1, block2, spatial_attn, temporal_attn, downsample in self.downs:
             x = block1(x, t)
             x = block2(x, t)
@@ -874,7 +874,7 @@ class Trainer(object):
         }
         torch.save(data, str(self.results_folder / f'model-{milestone}.pt'))
 
-    def load(self, milestone):
+    def load(self, milestone, **kwargs):
         if milestone == -1:
             all_milestones = [int(p.stem.split('-')[-1]) for p in Path(self.results_folder).glob('**/*.pt')]
             assert len(all_milestones) > 0, 'need to have at least one milestone to load from latest checkpoint (milestone == -1)'
@@ -883,8 +883,8 @@ class Trainer(object):
         data = torch.load(str(self.results_folder / f'model-{milestone}.pt'))
 
         self.step = data['step']
-        self.model.load_state_dict(data['model'])
-        self.ema_model.load_state_dict(data['ema'])
+        self.model.load_state_dict(data['model'], **kwargs)
+        self.ema_model.load_state_dict(data['ema'], **kwargs)
         self.scaler.load_state_dict(data['scaler'])
 
     def train(
